@@ -1,6 +1,9 @@
 mod calculator;
 mod errors;
 mod eval;
+mod expression;
+#[cfg(test)]
+mod macros;
 mod parse;
 
 pub use {crate::calculator::Calculator, errors::Error};
